==> wstx-impl-2.1-b21-sources.jar: com/sun/xml/ws/tx/at/internal/WSATGatewayRMPeerRecoveryDelegate.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.xml.ws.tx.at.internal;

import javax.transaction.xa.XAException;
import javax.transaction.xa.XAResource;
import javax.transaction.xa.Xid;


/**
 * Delegates to WSATGatewayRM for peer/delegate recovery.
 * The main/only purpose of this class is the special recover call made on WSATGatewayRM to identify the instance
 *  and/for log location
*
* @author paulparkinson
*/
public class WSATGatewayRMPeerRecoveryDelegate implements XAResource {
    String peerLogLocation;


    public WSATGatewayRMPeerRecoveryDelegate(String peerLogLocation) {
        this.peerLogLocation = peerLogLocation;
    }

    public void commit(Xid xid, boolean b) throws XAException {
        WSATGatewayRM.getInstance().commit(xid, b);
    }

    public void end(Xid xid, int i) throws XAException {
        WSATGatewayRM.getInstance().end(xid, i);
    }

    public void forget(Xid xid) throws XAException {
        WSATGatewayRM.getInstance().forget(xid);
    }

    public int getTransactionTimeout() throws XAException {
        return WSATGatewayRM.getInstance().getTransactionTimeout();
    }

    public boolean isSameRM(XAResource xaResource) throws XAException {
        return WSATGatewayRM.getInstance().isSameRM(xaResource);
    }

    public int prepare(Xid xid) throws XAException {
        return WSATGatewayRM.getInstance().prepare(xid);
    }
    
    public Xid[] recover(int i) throws XAException {
            return WSATGatewayRM.getInstance().recover(i, peerLogLocation);
    }

    public void rollback(Xid xid) throws XAException {
        WSATGatewayRM.getInstance().rollback(xid);
    }

    public boolean setTransactionTimeout(int i) throws XAException {
        return WSATGatewayRM.getInstance().setTransactionTimeout(i);
    }

    public void start(Xid xid, int i) throws XAException {
        WSATGatewayRM.getInstance().start(xid, i);
    }
}

==> wstx-impl-3.0.1-sources.jar: com/sun/xml/ws/tx/at/internal/WSATGatewayRMPeerRecoveryDelegate.java <==
/*
 * Copyright (c) 1997, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package com.sun.xml.ws.tx.at.internal;

import javax.transaction.xa.XAException;
import javax.transaction.xa.XAResource;
import javax.transaction.xa.Xid;


/**
 * Delegates to WSATGatewayRM for peer/delegate recovery.
 * The main/only purpose of this class is the special recover call made on WSATGatewayRM to identify the instance
 *  and/for log location
*
* @author paulparkinson
*/
public class WSATGatewayRMPeerRecoveryDelegate implements XAResource {
    String peerLogLocation;


    public WSATGatewayRMPeerRecoveryDelegate() {
    }

    public WSATGatewayRMPeerRecoveryDelegate(String peerLogLocation) {
        this.peerLogLocation = peerLogLocation;
    }

    public void commit(Xid xid, boolean b) throws XAException {
        WSATGatewayRM.getInstance().commit(xid, b);
    }

    public void end(Xid xid, int i) throws XAException {
        WSATGatewayRM.getInstance().end(xid, i);
    }

    public void forget(Xid xid) throws XAException {
        WSATGatewayRM.getInstance().forget(xid);
    }

    public int getTransactionTimeout() throws XAException {
        return WSATGatewayRM.getInstance().getTransactionTimeout();
    }

    public boolean isSameRM(XAResource xaResource) throws XAException {
        return WSATGatewayRM.getInstance().isSameRM(xaResource);
    }

    public int prepare(Xid xid) throws XAException {
        return WSATGatewayRM.getInstance().prepare(xid);
    }
    
    public Xid[] recover(int i) throws XAException {
            return peerLogLocation==null?
                    WSATGatewayRM.getInstance().recover(i):
                    WSATGatewayRM.getInstance().recover(i, peerLogLocation);
    }

    public void rollback(Xid xid) throws XAException {
        WSATGatewayRM.getInstance().rollback(xid);
    }

    public boolean setTransactionTimeout(int i) throws XAException {
        return WSATGatewayRM.getInstance().setTransactionTimeout(i);
    }

    public void start(Xid xid, int i) throws XAException {
        WSATGatewayRM.getInstance().start(xid, i);
    }
}
